@@ -6,12 +6,9 @@ import time
 from inspect import isgeneratorfunction, ismethod
 from collections import deque, namedtuple
 
-from ..hioing import ValidationError, VersionError
 from .. import hioing
 from .basing import State
 from . import tyming
-from ..core.tcp import serving, clienting
-from ..core.serial import serialing
 from ..help import timing, helping
 
 
@@ -177,7 +174,7 @@ class Doist(tyming.Tymist):
 
                 except Exception:  # Unknown exception
                     raise
-            
+
         finally: # finally clause always runs regardless of exception or not.
             self.close()  # force close remaining deeds throws GeneratorExit
 
@@ -1169,246 +1166,6 @@ class DoDoer(Doer):
         self.exit(doeds=(rdoers, rdeeds))
 
 
-class ServerDoer(Doer):
-    """
-    Basic TCP Server
-
-    See Doer for inherited attributes, properties, and methods.
-
-    Attributes:
-       .server is TCP Server instance
-
-    Properties:
-
-    """
-
-    def __init__(self, server, **kwa):
-        """
-        Initialize
-
-        Parameters:
-           server is TCP Server instance
-        """
-        super(ServerDoer, self).__init__(**kwa)
-        self.server = server
-        if self.tymth:
-            self.server.wind(self.tymth)
-
-
-    def wind(self, tymth):
-        """
-        Inject new tymist.tymth as new ._tymth. Changes tymist.tyme base.
-        Updates winds .tymer .tymth
-        """
-        super(ServerDoer, self).wind(tymth)
-        self.server.wind(tymth)
-
-
-    def enter(self):
-        """"""
-        self.server.reopen()
-
-
-    def recur(self, tyme):
-        """"""
-        self.server.service()
-
-
-    def exit(self):
-        """"""
-        self.server.close()
-
-
-class EchoServerDoer(ServerDoer):
-    """
-    Echo TCP Server
-    Just echoes back to client whatever it receives from client
-
-    See Doer for inherited attributes, properties, and methods.
-
-    Inherited Attributes:
-        .server is TCP Server instance
-
-
-    """
-
-    def enter(self):
-        """"""
-        self.server.reopen()
-
-
-    def recur(self, tyme):
-        """"""
-        self.server.service()
-        for ca, ix in self.server.ixes.items():  # echo back
-            if ix.rxbs:
-                ix.tx(bytes(ix.rxbs))
-                ix.clearRxbs()
-
-
-    def exit(self):
-        """"""
-        self.server.close()
-
-
-class ClientDoer(Doer):
-    """
-    Basic TCP Client
-
-    See Doer for inherited attributes, properties, and methods.
-
-    Attributes:
-       .client is TCP Client instance
-
-    """
-
-    def __init__(self, client, **kwa):
-        """
-        Initialize instance.
-
-        Parameters:
-           client is TCP Client instance
-        """
-        super(ClientDoer, self).__init__(**kwa)
-        self.client = client
-        if self.tymth:
-            self.client.wind(self.tymth)
-
-
-    def wind(self, tymth):
-        """
-        Inject new tymist.tymth as new ._tymth. Changes tymist.tyme base.
-        Updates winds .tymer .tymth
-        """
-        super(ClientDoer, self).wind(tymth)
-        self.client.wind(tymth)
-
-
-    def enter(self):
-        """"""
-        self.client.reopen()
-
-
-    def recur(self, tyme):
-        """"""
-        self.client.service()
-
-
-    def exit(self):
-        """"""
-        self.client.close()
-
-
-class ConsoleDoer(Doer):
-    """
-    Basic Console Doer. Wraps console in doer context so opens and closes console
-
-    To test in WingIde must configure Debug I/O to use external console
-    See Doer for inherited attributes, properties, and methods.
-
-    Attributes:
-       .console is serial Console instance
-
-    """
-
-    def __init__(self, console, **kwa):
-        """
-        Initialize instance.
-
-        Parameters:
-           console is serial Console instance
-
-        """
-        super(ConsoleDoer, self).__init__(**kwa)
-        self.console = console
-
-
-    def enter(self):
-        """"""
-        result = self.console.reopen()
-
-
-    def exit(self):
-        """"""
-        self.console.close()
-
-
-class EchoConsoleDoer(Doer):
-    """
-    Basic Terminal Console IO to buffers. Echos input back to output
-
-    To test in WingIde must configure Debug I/O to use external console
-
-    See Doer for inherited attributes, properties, and methods.
-
-    Attributes:
-       .console is serial Console instance
-
-    """
-
-    def __init__(self, console, lines=None, txbs=None, **kwa):
-        """
-        Initialize instance.
-
-        Parameters:
-           console is serial Console instance
-           lines is deque of input bytes bytearrays of each line from console
-           txbs is ouput bytes bytearray to send to console
-
-        """
-        super(EchoConsoleDoer, self).__init__(**kwa)
-        self.console = console
-        self.lines = lines if lines is not None else deque()
-        self.txbs = txbs if txbs is not None else bytearray()
-
-
-    def enter(self):
-        """"""
-        self.console.reopen()
-        self.txbs.extend(b"Cmds: q=quit, h=help otherwise echoes.\n")
-        self.txbs.extend(b"Type cmd & \n: ")
-
-
-    def recur(self, tyme):
-        """"""
-        done = False
-        prompt = False
-        while self.lines:
-            line = self.lines.popleft()
-            #process line here
-            if line == b'q':
-                self.txbs.extend(b"Goodbye\n.")
-                done = True  #  all done so indicate exit
-                break
-
-            elif line == b'h':
-                self.txbs.extend(b"Help: type q to quit or h for help.\n")
-
-            else:
-                self.txbs.extend(b"Echo: %s\n" % line )
-
-            prompt = True
-
-        if prompt:
-            self.txbs.extend(b"Type cmd & \n: ")
-
-
-        if self.txbs:
-            count =  self.console.put(self.txbs)  #  write
-            del self.txbs[:count]
-
-        line = self.console.get()  #  read
-        if line:
-            self.lines.append(line)
-
-
-        return done  # keep going if done == False else ends
-
-    def exit(self):
-        """"""
-        self.console.close()
-
-
 def bareDo(tymth=None, tock=0.0, **opts):
     """
     Bare bones generator function template as example of generator function
