@@ -11,10 +11,13 @@ import ssl
 
 from contextlib import contextmanager
 
-from ...base import tyming
+
+from ... import help
+from ...base import tyming, doing
 from .. import coring
 
 
+logger = help.ogler.getLogger()
 
 @contextmanager
 def openClient(cls=None, **kwa):
@@ -58,11 +61,11 @@ class Client(tyming.Tymee):
     Methods:
 
     """
-    Timeout = 0.0  # timeout in seconds, timeout of 0.0 means ignore timeout
+    Tymeout = 0.0  # tymeout in seconds, tymeout of 0.0 means ignore tymeout
     Reconnectable = False  # auto reconnect flag
 
     def __init__(self,
-                 timeout=None,
+                 tymeout=None,
                  ha=None,
                  host='127.0.0.1',
                  port=56000,
@@ -78,7 +81,7 @@ class Client(tyming.Tymee):
         Parameters:
             tymth is injected function wrapper closure returned by .tymen() of
                 Tymist instance. Calling tymth() returns associated Tymist .tyme.
-            timeout = auto reconnect retry timeout
+            tymeout = auto reconnect retry tymeout
             ha = host address duple (host, port) of remote server
             host = host address or tcp server to connect to
             port = socket port
@@ -89,8 +92,8 @@ class Client(tyming.Tymee):
             wl = WireLog object if any
         """
         super(Client, self).__init__(**kwa)
-        self.timeout = timeout if timeout is not None else self.Timeout
-        self.tymer = tyming.Tymer(tymth=self.tymth, duration=self.timeout)  # reconnect retry timer
+        self.tymeout = tymeout if tymeout is not None else self.Tymeout
+        self.tymer = tyming.Tymer(tymth=self.tymth, duration=self.tymeout)  # reconnect retry timer
         self.reinitHostPort(ha=ha, hostname=host, port=port)
         self.ha = ha or (host, port)
         host, port = self.ha
@@ -319,7 +322,7 @@ class Client(tyming.Tymee):
         try:
             result = self.cs.connect_ex(self.ha)  # async connect
         except socket.error as ex:
-            console.terse("socket.error = {0}\n".format(ex))
+            logger.error("socket.error = %s\n", ex)
             raise
 
         if result not in [0, errno.EISCONN]:  # not connected
@@ -358,7 +361,7 @@ class Client(tyming.Tymee):
             self.connect()  # if successful sets .accepted .connected to True
 
             if not self.connected and self.reconnectable:
-                if self.timeout > 0.0 and self.tymer.expired:  # timed out
+                if self.tymeout > 0.0 and self.tymer.expired:  # timed out
                     self.reopen()
                     self.tymer.restart()
 
@@ -506,7 +509,6 @@ class ClientTls(Client):
     Methods:
     """
     def __init__(self,
-                 tymth,
                  context=None,
                  version=None,
                  certify=None,
@@ -540,7 +542,7 @@ class ClientTls(Client):
             hostify = verify server hostName If None use default
             certedhost = server's certificate common name (hostname) to check against
         """
-        super(ClientTls, self).__init__(tymth=tymth, **kwa)
+        super(ClientTls, self).__init__(**kwa)
 
         self._connected = False  # attributed supporting connected property
 
@@ -737,3 +739,53 @@ class ClientTls(Client):
 
         return result
 
+
+
+class ClientDoer(doing.Doer):
+    """
+    Basic TCP Client
+
+    See Doer for inherited attributes, properties, and methods.
+
+    Attributes:
+       .client is TCP Client instance
+
+    """
+
+    def __init__(self, client, **kwa):
+        """
+        Initialize instance.
+
+        Parameters:
+           client is TCP Client instance
+        """
+        super(ClientDoer, self).__init__(**kwa)
+        self.client = client
+        if self.tymth:
+            self.client.wind(self.tymth)
+
+
+    def wind(self, tymth):
+        """
+        Inject new tymist.tymth as new ._tymth. Changes tymist.tyme base.
+        Updates winds .tymer .tymth
+        """
+        super(ClientDoer, self).wind(tymth)
+        self.client.wind(tymth)
+
+
+    def enter(self):
+        """"""
+        self.client.reopen()
+
+
+    def recur(self, tyme):
+        """"""
+        self.client.service()
+
+
+    def exit(self):
+        """"""
+        self.client.close()
+
+
